@@ -1,6 +1,7 @@
 from cyberfusion.CoreApiClient import models
 from typing import Optional
 
+from cyberfusion.CoreApiClient._helpers import construct_includes_query_parameter
 from cyberfusion.CoreApiClient.http import DtoResponse
 from cyberfusion.CoreApiClient.interfaces import Resource
 
@@ -13,7 +14,7 @@ class BorgRepositories(Resource):
         local_response = self.api_connector.send_or_fail(
             "POST",
             "/api/v1/borg-repositories",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -25,6 +26,7 @@ class BorgRepositories(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.BorgRepositoriesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.BorgRepositoryResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -34,9 +36,12 @@ class BorgRepositories(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (
+                include_filters.model_dump(exclude_unset=True)
+                if include_filters
+                else {}
+            )
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.BorgRepositoryResource)
@@ -45,12 +50,13 @@ class BorgRepositories(Resource):
         self,
         *,
         id_: int,
+        includes: list[str] | None = None,
     ) -> DtoResponse[models.BorgRepositoryResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/borg-repositories/{id_}",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.BorgRepositoryResource)
@@ -64,7 +70,7 @@ class BorgRepositories(Resource):
         local_response = self.api_connector.send_or_fail(
             "PATCH",
             f"/api/v1/borg-repositories/{id_}",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
