@@ -1,6 +1,7 @@
 from cyberfusion.CoreApiClient import models
 
 from cyberfusion.CoreApiClient.interfaces import Resource
+from cyberfusion.CoreApiClient._helpers import construct_includes_query_parameter
 from cyberfusion.CoreApiClient.http import DtoResponse
 
 
@@ -12,7 +13,7 @@ class HAProxyListensToNodes(Resource):
         local_response = self.api_connector.send_or_fail(
             "POST",
             "/api/v1/haproxy-listens-to-nodes",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -26,6 +27,7 @@ class HAProxyListensToNodes(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.HaproxyListensToNodesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.HAProxyListenToNodeResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -35,9 +37,12 @@ class HAProxyListensToNodes(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (
+                include_filters.model_dump(exclude_unset=True)
+                if include_filters
+                else {}
+            )
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -48,12 +53,13 @@ class HAProxyListensToNodes(Resource):
         self,
         *,
         id_: int,
+        includes: list[str] | None = None,
     ) -> DtoResponse[models.HAProxyListenToNodeResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/haproxy-listens-to-nodes/{id_}",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
