@@ -13,7 +13,7 @@ class HtpasswdFiles(Resource):
         local_response = self.api_connector.send_or_fail(
             "POST",
             "/api/v1/htpasswd-files",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -35,7 +35,11 @@ class HtpasswdFiles(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | (
+                include_filters.model_dump(exclude_unset=True)
+                if include_filters
+                else {}
+            )
             | construct_includes_query_parameter(includes),
         )
 
