@@ -14,7 +14,7 @@ class MailAccounts(Resource):
         local_response = self.api_connector.send_or_fail(
             "POST",
             "/api/v1/mail-accounts",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -36,7 +36,11 @@ class MailAccounts(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | (
+                include_filters.model_dump(exclude_unset=True)
+                if include_filters
+                else {}
+            )
             | construct_includes_query_parameter(includes),
         )
 
@@ -66,7 +70,7 @@ class MailAccounts(Resource):
         local_response = self.api_connector.send_or_fail(
             "PATCH",
             f"/api/v1/mail-accounts/{id_}",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
