@@ -1,7 +1,8 @@
 from cyberfusion.CoreApiClient import models
-from typing import Optional, List
+from typing import Optional
 
 from cyberfusion.CoreApiClient.interfaces import Resource
+from cyberfusion.CoreApiClient._helpers import construct_includes_query_parameter
 from cyberfusion.CoreApiClient.http import DtoResponse
 
 
@@ -13,7 +14,7 @@ class PassengerApps(Resource):
         local_response = self.api_connector.send_or_fail(
             "POST",
             "/api/v1/passenger-apps/nodejs",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -22,21 +23,25 @@ class PassengerApps(Resource):
     def list_passenger_apps(
         self,
         *,
-        skip: Optional[int] = None,
-        limit: Optional[int] = None,
-        filter_: Optional[List[str]] = None,
-        sort: Optional[List[str]] = None,
+        page: int = 1,
+        per_page: int = 0,
+        include_filters: models.PassengerAppsSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.PassengerAppResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             "/api/v1/passenger-apps",
             data=None,
             query_parameters={
-                "skip": skip,
-                "limit": limit,
-                "filter": filter_,
-                "sort": sort,
-            },
+                "page": page,
+                "per_page": per_page,
+            }
+            | (
+                include_filters.model_dump(exclude_unset=True)
+                if include_filters
+                else {}
+            )
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.PassengerAppResource)
@@ -45,9 +50,13 @@ class PassengerApps(Resource):
         self,
         *,
         id_: int,
+        includes: list[str] | None = None,
     ) -> DtoResponse[models.PassengerAppResource]:
         local_response = self.api_connector.send_or_fail(
-            "GET", f"/api/v1/passenger-apps/{id_}", data=None, query_parameters={}
+            "GET",
+            f"/api/v1/passenger-apps/{id_}",
+            data=None,
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.PassengerAppResource)
@@ -61,7 +70,7 @@ class PassengerApps(Resource):
         local_response = self.api_connector.send_or_fail(
             "PATCH",
             f"/api/v1/passenger-apps/{id_}",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
