@@ -14,7 +14,7 @@ class UNIXUsers(Resource):
         local_response = self.api_connector.send_or_fail(
             "POST",
             "/api/v1/unix-users",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -36,7 +36,11 @@ class UNIXUsers(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | (
+                include_filters.model_dump(exclude_unset=True)
+                if include_filters
+                else {}
+            )
             | construct_includes_query_parameter(includes),
         )
 
@@ -66,7 +70,7 @@ class UNIXUsers(Resource):
         local_response = self.api_connector.send_or_fail(
             "PATCH",
             f"/api/v1/unix-users/{id_}",
-            data=request.dict(exclude_unset=True),
+            data=request.model_dump(exclude_unset=True),
             query_parameters={},
         )
 
@@ -109,14 +113,14 @@ class UNIXUsers(Resource):
     def list_unix_user_usages(
         self,
         *,
-        unix_user_id: int,
+        id_: int,
         timestamp: str,
         time_unit: Optional[models.UNIXUserUsageResource] = None,
         includes: list[str] | None = None,
     ) -> DtoResponse[list[models.UNIXUserUsageResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
-            f"/api/v1/unix-users/usages/{unix_user_id}",
+            f"/api/v1/unix-users/{id_}/usages",
             data=None,
             query_parameters={
                 "timestamp": timestamp,
